=============================
Python MicorService framework
=============================

Main propose of this framework provide an independent architecture
and it should be used for any python framework (Django, Flask, Odoo).
